abacusai.deployment_conversation_event — AbacusAI documentation

# abacusai.deployment_conversation_event

## Classes

`DeploymentConversationEvent` | A single deployment conversation message.

## Module Contents

class abacusai.deployment_conversation_event.DeploymentConversationEvent(client, role=None, text=None, timestamp=None, messageIndex=None, regenerateAttempt=None, modelVersion=None, searchResults=None, isUseful=None, feedback=None, feedbackType=None, docInfos=None, keywordArguments=None, inputParams=None, attachments=None, responseVersion=None, agentWorkflowNodeId=None, nextAgentWorkflowNodeId=None, chatType=None, agentResponse=None, error=None, segments=None, streamedData=None, streamedSectionData=None, highlights=None, llmDisplayName=None, llmBotIcon=None, formResponse=None, routedLlm=None, computePointsUsed=None, computerFiles=None, toolUseRequest=None, verificationSummary=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A single deployment conversation message.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - role (str) – The role of the message sender

    - text (str) – The text of the message

    - timestamp (str) – The timestamp at which the message was sent

    - messageIndex (int) – The index of the message in the conversation

    - regenerateAttempt (int) – The sequence number of regeneration. Not regenerated if 0.

    - modelVersion (str) – The model instance id associated with the message.

    - searchResults (dict) – The search results for the message.

    - isUseful (bool) – Whether this message was marked as useful or not

    - feedback (str) – The feedback provided for the message

    - feedbackType (str) – The type of feedback provided for the message

    - docInfos (list) – A list of information on the documents associated with the message

    - keywordArguments (dict) – User message only. A dictionary of keyword arguments used to generate response.

    - inputParams (dict) – User message only. A dictionary of input parameters used to generate response.

    - attachments (list) – A list of attachments associated with the message.

    - responseVersion (str) – The version of the response, used to differentiate w/ legacy agent response.

    - agentWorkflowNodeId (str) – The workflow node id associated with the agent response.

    - nextAgentWorkflowNodeId (str) – The id of the workflow node to be executed next.

    - chatType (str) – The type of chat llm that was run for the message.

    - agentResponse (dict) – Response from the agent. Only for conversation with agents.

    - error (str) – The error message in case of an error.

    - segments (list) – The segments of the message.

    - streamedData (str) – Aggregated streamed messages from the agent.

    - streamedSectionData (str) – Aggregated streamed section outputs from the agent in a list.

    - highlights (dict) – Chunks with bounding boxes for highlighting the result sources.

    - llmDisplayName (str) – The display name of the LLM model used to generate the response. Only used for system-created bots.

    - llmBotIcon (str) – The icon location of the LLM model used to generate the response. Only used for system-created bots.

    - formResponse (dict) – Contains form data response from the user when a Form Segment is given out by the bot.

    - routedLlm (str) – The LLM that was chosen by RouteLLM to generate the response.

    - computePointsUsed (int) – The number of compute points used for the message.

    - computerFiles (list) – The list of files that were created by the computer agent.

    - toolUseRequest (dict) – The tool use request for the message.

    - verificationSummary (str) – The summary of the verification process for the message.

  role = None
  text = None
  timestamp = None
  message_index = None
  regenerate_attempt = None
  model_version = None
  search_results = None
  is_useful = None
  feedback = None
  feedback_type = None
  doc_infos = None
  keyword_arguments = None
  input_params = None
  attachments = None
  response_version = None
  agent_workflow_node_id = None
  next_agent_workflow_node_id = None
  chat_type = None
  agent_response = None
  error = None
  segments = None
  streamed_data = None
  streamed_section_data = None
  highlights = None
  llm_display_name = None
  llm_bot_icon = None
  form_response = None
  routed_llm = None
  compute_points_used = None
  computer_files = None
  tool_use_request = None
  verification_summary = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict